@@ -1,24 +1,34 @@
+import os
+
 from . import utils
 
 
 class IgnoreStorage:
     def __init__(self, dir_path: str):
-        self._path = utils.remove_suffix(dir_path, "/") + "/"
         self._dirs = []
         self._files = []
-        self._read_ignore_file()
+        self._root_dir = dir_path.rstrip("/")
+        self.load()
 
-    def _read_ignore_file(self):
+    def load(self):
+        for subdir, dirs, files in os.walk(self._root_dir):
+            subdir = utils.replace_backslashes(subdir)
+            for file in files:
+                if file == "mpbridge.ignore":
+                    self._load_ignore_file(abs_dir=subdir.rstrip("/"))
+
+    def _load_ignore_file(self, abs_dir: str):
+        rel_dir = utils.remove_prefix(abs_dir, self._root_dir)
         try:
-            with open(f"{self._path}mpbridge.ignore", "r") as file:
+            with open(f"{abs_dir}/mpbridge.ignore", "r") as file:
                 for line in utils.replace_backslashes(file.read()).split("\n"):
                     if not "".join(line.split()):
                         continue
                     line = "/" + line.lstrip("/")
-                    if not line.endswith("/"):
-                        self._files.append(line)
+                    if line.endswith("/"):
+                        self._dirs.append(f"{rel_dir}{line.rstrip('/')}/")
                     else:
-                        self._dirs.append(line.rstrip("/") + "/")
+                        self._files.append(f"{rel_dir}{line}")
         except FileNotFoundError:
             pass
         except:
